@@ -1,5 +1,5 @@
 /*  SMTUBE2, a small YouTube browser for SMPlayer
-    Copyright (C) 2015 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2015-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 #include "ui_configdialog.h"
 
 #include <QDialog>
+#include <QFont>
 
 #ifdef USE_PLAYERS
 #include "players.h"
@@ -38,17 +39,44 @@ public:
 	void setPlaybackQuality(int quality);
 	int playbackQuality();
 
+#ifdef D_BUTTON
+	void setAddDownloadButton(bool b);
+	bool addDownloadButton();
+
+	void setExternalDownloadUrl(const QString &);
+	QString externalDownloadUrl();
+#endif
+
+	void setDefaultFont(const QFont & f);
+	QFont defaultFont();
+
+#ifdef STYLE_SWITCHING
+	void setStyle(const QString & style);
+	QString style();
+#endif
+
 #ifdef USE_PLAYERS
 	void setPlayers(QList<Player> list);
 	QList<Player> players();
 
+	void setDefaultPlayers(QList<Player> players);
+
 protected slots:
 	void on_up_button_clicked();
 	void on_down_button_clicked();
 	void on_delete_button_clicked();
 	void on_add_button_clicked();
 	void editCurrentItem();
+	void on_addplayers_button_clicked();
+
+	void updateAddPlayersButton();
+
+protected:
+	QList<Player> default_players;
 #endif
+
+protected slots:
+	void on_change_font_button_clicked();
 };
 
 #endif
