@@ -1,5 +1,5 @@
 /*  SMTUBE2, a small YouTube browser for SMPlayer
-    Copyright (C) 2015 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2015-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,12 +17,17 @@
 */
 
 #include "browserwindow.h"
+#include "version.h"
 #include <QApplication>
 #include <QDir>
 #include <QTranslator>
 #include <QLibraryInfo>
 #include <QDebug>
 
+#ifdef HDPI_SUPPORT
+#include "hdpisupport.h"
+#endif
+
 QString configPath() {
 #ifdef PORTABLE_APP
 	return qApp->applicationDirPath();
@@ -41,7 +46,7 @@ QString configPath() {
 #endif // PORTABLE_APP
 }
 
-#ifdef YT_USE_SCRIPT
+#if defined(YT_USE_YTSIG) || defined(HDPI_SUPPORT)
 QString smplayerConfigPath() {
 #ifdef PORTABLE_APP
 	return qApp->applicationDirPath();
@@ -59,7 +64,7 @@ QString smplayerConfigPath() {
 #endif
 #endif // PORTABLE_APP
 }
-#endif // YT_USE_SCRIPT
+#endif // YT_USE_YTSIG
 
 
 QString translationsPath() {
@@ -68,11 +73,15 @@ QString translationsPath() {
 #endif
 
 	QString path = "translations";
-#if !defined(Q_OS_WIN)
-#ifdef TRANSLATION_PATH
+#ifdef Q_OS_WIN
+	if (!QDir().exists(path)) {
+		path = qApp->applicationDirPath() + "/translations";
+	}
+#else
+	#ifdef TRANSLATION_PATH
 	QString s = QString(TRANSLATION_PATH);
 	if (!s.isEmpty()) path = s;
-#endif
+	#endif
 #endif
 	qDebug() << "Translations path:" << path;
 	return path;
@@ -87,7 +96,23 @@ QString qtTranslationsPath() {
 }
 
 int main(int argc, char * argv[]) {
+#ifdef HDPI_SUPPORT
+	HDPISupport * hdpi = new HDPISupport(smplayerConfigPath());
+#endif
+
 	QApplication a(argc, argv);
+	a.setApplicationName("smtube");
+
+#if QT_VERSION >= 0x040400
+	a.setApplicationVersion(smtubeVersion());
+
+	// Enable icons in menus
+	a.setAttribute(Qt::AA_DontShowIconsInMenus, false);
+#endif
+
+#ifdef HDPI_SUPPORT
+	delete hdpi;
+#endif
 
 	QUrl url;
 	QString search_term;
@@ -123,6 +148,12 @@ int main(int argc, char * argv[]) {
 
 	a.installTranslator(&app_trans);
 	a.installTranslator(&qt_trans);
+	
+	#if QT_VERSION >= 0x050000
+	QTranslator qtbase_trans;
+	qtbase_trans.load("qtbase_" + locale, qtTranslationsPath());
+	a.installTranslator(&qtbase_trans);
+	#endif
 
 	if (!QFile::exists(configPath())) {
 		qDebug() << "Creating" << configPath();
@@ -131,7 +162,7 @@ int main(int argc, char * argv[]) {
 
 	BrowserWindow * w = new BrowserWindow(configPath());
 
-#ifdef YT_USE_SCRIPT
+#ifdef YT_USE_YTSIG
 	QString ytcode_name = "yt.js";
 	QString ytcode_file = configPath() +"/"+ ytcode_name;
 	if (QFile::exists(smplayerConfigPath())) ytcode_file = smplayerConfigPath() +"/"+ ytcode_name;
