@@ -1,5 +1,5 @@
 /*  SMTUBE2, a small YouTube browser for SMPlayer
-    Copyright (C) 2015 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2015-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,12 +34,21 @@ public:
 	void setName(const QString & name);
 	void setBinary(const QString & binary);
 	void setParameters(const QString & parms);
-	void setDirectPlay(bool b);
+	void setSupportStreamingSites(bool b);
+	void setSupportOnlineTV(bool b);
+	void setMedia(int m);
+	void setQuality(int q);
 
 	QString name();
 	QString binary();
 	QString parameters();
-	bool directPlay();
+	bool supportStreamingSites();
+	bool supportOnlineTV();
+	int media();
+	int quality();
+
+protected slots:
+	void streamingSitesChanged(bool);
 };
 
 #endif
