@@ -1,5 +1,5 @@
 /*  smtube, a small youtube browser.
-    Copyright (C) 2012-2015 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2012-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,34 +28,49 @@ class QSettings;
 class Player
 {
 public:
-	Player(QString name, QString binary, QString arguments, bool directPlay) {
+	enum Media { None = 0, Video = 1, Audio = 2, VideoAudio = 3 };
+
+	Player(QString name, QString binary, QString arguments,
+			bool support_for_streaming_sites, bool support_for_online_tv,
+			Media media, int preferred_quality = -1)
+	{
 		player_name = name;
 		player_bin = binary;
 		args = arguments;
-		direct_play = directPlay;
+		support_streaming_sites = support_for_streaming_sites;
+		support_online_tv = support_for_online_tv,
+		supported_media = media;
+		quality = preferred_quality;
 	}
 
 	void setName(QString name) { player_name = name; }
 	void setBinary(QString binary) { player_bin = binary; }
 	void setArguments(QString arguments) { args = arguments; }
-	void setDirectPlay(bool b) { direct_play = b; }
+	void setSupportStreamingSites(bool b) { support_streaming_sites = b; }
+	void setSupportOnlineTV(bool b) { support_online_tv = b; }
+	void setSupportedMedia(Media m) { supported_media = m; }
+	void setPreferredQuality(int q) { quality = q; }
 
 	QString name() { return player_name; }
 	QString binary() { return player_bin; }
 	QString arguments() { return args; };
-	bool directPlay() { return direct_play; }
+	bool supportStreamingSites() { return support_streaming_sites; }
+	bool supportOnlineTV() { return support_online_tv; }
+	Media supportedMedia() { return supported_media; }
+	int preferredQuality() { return quality; }
 
 	QString executable(bool * found = 0);
 
-	static QString directPlayToString(bool b);
-
 protected:
 #ifdef Q_OS_LINUX
 	QString findExecutable(const QString & name);
 #endif
 
 	QString player_name, player_bin, args;
-	bool direct_play;
+	bool support_streaming_sites;
+	bool support_online_tv;
+	Media supported_media;
+	int quality;
 };
 
 
@@ -81,8 +96,12 @@ public:
 	void setAllPlayers(QList<Player> players);
 	QList<Player> allPlayers() { return list; }
 
+	QList<Player> defaultPlayers() { return default_list; }
+
 protected:
-	QList <Player> list;
+	QList<Player> list;
+	QList<Player> default_list;
+
 	int curr;
 
 	QList <Player> available_players_cache;
