@@ -1,5 +1,5 @@
 /*  SMTUBE2, a small YouTube browser for SMPlayer
-    Copyright (C) 2015 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2015-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 #include "supportedurls.h"
 
 QList<QRegExp> SupportedUrls::list;
+QList<QRegExp> SupportedUrls::ds_list;
 QRegExp SupportedUrls::ytrx;
 
 int SupportedUrls::site(const QString & url) {
@@ -28,7 +29,13 @@ int SupportedUrls::site(const QString & url) {
 
 	for (int n = 0; n < list.count(); n++) {
 		if (list[n].indexIn(url) > -1) {
-			return Other;
+			return StreamingSite;
+		}
+	}
+
+	for (int n = 0; n < ds_list.count(); n++) {
+		if (ds_list[n].indexIn(url) > -1) {
+			return DirectStream;
 		}
 	}
 
@@ -36,8 +43,10 @@ int SupportedUrls::site(const QString & url) {
 }
 
 void SupportedUrls::load() {
-	ytrx = QRegExp("^(https?\\:\\/\\/)?(www\\.)?youtube\\.com\\/watch\\?v=.+$");
+	ytrx = QRegExp("^(https?\\:\\/\\/)?(www\\.|m\\.)?youtube\\.com\\/watch\\?v=.+$");
 
 	list << QRegExp("^(https?\\:\\/\\/)?(www\\.)?dailymotion\\.com\\/video\\/.+$");
 	list << QRegExp("^(https?\\:\\/\\/)?(www\\.)?vimeo\\.com\\/(channels\\/staffpicks\\/)?\\d+$");
+
+	ds_list << QRegExp("^(https?\\:\\/\\/).*m3u8?\\??");
 }
