@@ -1,5 +1,5 @@
 /*  SMTUBE2, a small YouTube browser for SMPlayer
-    Copyright (C) 2015 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2015-2018 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,13 +24,14 @@
 
 class SupportedUrls {
 public:
-	enum SiteID { Youtube = 1, Other = 2, Unsupported = 0 };
+	enum SiteID { Youtube = 1, StreamingSite = 2, DirectStream = 3, Unsupported = 0 };
 
 	static int site(const QString & url);
 	static void load();
 
 private:
 	static QList<QRegExp> list;
+	static QList<QRegExp> ds_list;
 	static QRegExp ytrx;
 };
 
