@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="es_ES">
+<TS version="2.0" language="es">
 <context>
     <name>About</name>
     <message>
@@ -24,56 +24,52 @@
         <translation>&amp;Licencia</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="33"/>
+        <location filename="../about.cpp" line="34"/>
         <source>YouTube%1 Browser for SMPlayer</source>
         <translation>Buscador de vídeos de YouTube%1 de SMPlayer</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="36"/>
+        <location filename="../about.cpp" line="37"/>
         <source>Version: %1</source>
         <translation>Versión: %1</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="38"/>
+        <location filename="../about.cpp" line="39"/>
         <source>Portable Edition</source>
         <translation>Edición Portable</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="41"/>
+        <location filename="../about.cpp" line="42"/>
         <source>Compiled with Qt %1 (using %2)</source>
         <translation>Compilado con Qt %1 (usando %2)</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="43"/>
+        <location filename="../about.cpp" line="44"/>
         <source>Visit our website for updates:</source>
         <translation>Visita nuestra web para conseguir actualizaciones:</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="86"/>
+        <location filename="../about.cpp" line="87"/>
         <source>Many people contributed with translations.</source>
         <translation>Muchas personas han contribuido con traducciones.</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="87"/>
+        <location filename="../about.cpp" line="88"/>
         <source>You can also help to translate SMTube into your own language.</source>
         <translation>Tú también puedes ayudar a traducir el SMTube a tu propio idioma.</translation>
     </message>
     <message>
-        <source>You can also help to translate SMPlayer into your own language.</source>
-        <translation type="obsolete">Tú también puedes ayudar a traducir el SMPlayer a tu propio idioma.</translation>
-    </message>
-    <message>
-        <location filename="../about.cpp" line="88"/>
+        <location filename="../about.cpp" line="89"/>
         <source>Visit %1 and join a translation team.</source>
         <translation>Visita %1 y únete a un equipo de traducción.</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="90"/>
+        <location filename="../about.cpp" line="91"/>
         <source>Click here to know the translators from the transifex teams</source>
         <translation>Pulsa aquí para conocer los traductores de los equipos de transifex</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="116"/>
+        <location filename="../about.cpp" line="117"/>
         <source>&lt;b&gt;%1&lt;/b&gt; (%2)</source>
         <translation>&lt;b&gt;%1&lt;/b&gt; (%2)</translation>
     </message>
@@ -81,178 +77,172 @@
 <context>
     <name>BrowserWindow</name>
     <message>
-        <location filename="../browserwindow.cpp" line="101"/>
+        <location filename="../browserwindow.cpp" line="125"/>
         <source>Home</source>
         <translation>Inicio</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="104"/>
+        <location filename="../browserwindow.cpp" line="128"/>
         <source>Navigation</source>
         <translation>Navegación</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="112"/>
+        <location filename="../browserwindow.cpp" line="136"/>
+        <source>Zoom +</source>
+        <translation>Zoom +</translation>
+    </message>
+    <message>
+        <location filename="../browserwindow.cpp" line="140"/>
+        <source>Zoom -</source>
+        <translation>Zoom -</translation>
+    </message>
+    <message>
+        <location filename="../browserwindow.cpp" line="144"/>
+        <source>&amp;Quit</source>
+        <translation>&amp;Salir</translation>
+    </message>
+    <message>
+        <location filename="../browserwindow.cpp" line="147"/>
+        <source>&amp;Navigation</source>
+        <translation>&amp;Navegación</translation>
+    </message>
+    <message>
+        <location filename="../browserwindow.cpp" line="159"/>
         <source>&amp;View</source>
         <translation>&amp;Ver</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="113"/>
+        <location filename="../browserwindow.cpp" line="160"/>
         <source>Toolbar</source>
         <translation>Barra de herramientas</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="117"/>
+        <location filename="../browserwindow.cpp" line="164"/>
         <source>Statusbar</source>
         <translation>Barra de estado</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="121"/>
+        <location filename="../browserwindow.cpp" line="168"/>
         <source>&amp;Settings</source>
         <translation>&amp;Configuración</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="128"/>
+        <location filename="../browserwindow.cpp" line="176"/>
         <source>&amp;Help</source>
         <translation>&amp;Ayuda</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="131"/>
+        <location filename="../browserwindow.cpp" line="179"/>
         <source>&amp;Update the YouTube code</source>
         <translation>Actualizar el código de &amp;YouTube</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="136"/>
+        <location filename="../browserwindow.cpp" line="185"/>
         <source>About this &amp;release</source>
         <translation>Acerca de esta &amp;version</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="140"/>
+        <location filename="../browserwindow.cpp" line="190"/>
         <source>&amp;About SMTube</source>
         <translation>&amp;Acerca de SMTube</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="343"/>
+        <location filename="../browserwindow.cpp" line="298"/>
+        <source>Download video using an external service</source>
+        <translation>Descargar el vídeo usando un servicio externo</translation>
+    </message>
+    <message>
+        <location filename="../browserwindow.cpp" line="299"/>
+        <source>Download</source>
+        <translation>Descargar</translation>
+    </message>
+    <message>
+        <location filename="../browserwindow.cpp" line="501"/>
         <source>Connection failed</source>
         <translation>Error en la conexión</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="344"/>
+        <location filename="../browserwindow.cpp" line="502"/>
         <source>The video you requested needs to open a HTTPS connection.</source>
         <translation>El vídeo que has solicitado necesita abrir una conexión HTTPS.</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="345"/>
+        <location filename="../browserwindow.cpp" line="503"/>
         <source>Unfortunately the OpenSSL component, required for it, is not available in your system.</source>
         <translation>Lamentablemente el componente OpenSSL, que es necesario para ello, no se encuentra en tu sistema.</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="350"/>
+        <location filename="../browserwindow.cpp" line="508"/>
         <source>No video found</source>
         <translation>No se ha encontrado el vídeo</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="351"/>
+        <location filename="../browserwindow.cpp" line="509"/>
         <source>It wasn&apos;t possible to find the URL for this video.</source>
         <translation>No ha sido posible encontrar la URL de este vídeo.</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="361"/>
-        <location filename="../browserwindow.cpp" line="369"/>
+        <location filename="../browserwindow.cpp" line="519"/>
+        <location filename="../browserwindow.cpp" line="527"/>
         <source>Problems with YouTube</source>
         <translation>Problemas con YouTube</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="362"/>
-        <location filename="../browserwindow.cpp" line="370"/>
+        <location filename="../browserwindow.cpp" line="520"/>
+        <location filename="../browserwindow.cpp" line="528"/>
         <source>Unfortunately due to changes in YouTube, the video &apos;%1&apos; can&apos;t be played.</source>
         <translation>Lamentablemente debido a cambios en YouTube, no es posible reproducir el vídeo &apos;%1&apos;.</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="363"/>
+        <location filename="../browserwindow.cpp" line="521"/>
         <source>Do you want to update the YouTube code? This may fix the problem.</source>
         <translation>¿Quieres actualizar el código de YouTube? Esto podría solucionar el problema.</translation>
     </message>
     <message>
-        <source>Problems with Youtube</source>
-        <translation type="obsolete">Problemas con Youtube</translation>
-    </message>
-    <message>
-        <source>Unfortunately due to changes in Youtube, the video &apos;%1&apos; can&apos;t be played.</source>
-        <translation type="obsolete">Lamentablemente debido a cambios en Youtube, no es posible reproducir el vídeo &apos;%1&apos;.</translation>
-    </message>
-    <message>
-        <source>Do you want to update the Youtube code? This may fix the problem.</source>
-        <translation type="obsolete">¿Quieres actualizar el código de Youtube? Esto podría solucionar el problema.</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="371"/>
+        <location filename="../browserwindow.cpp" line="529"/>
         <source>Maybe updating this application could fix the problem.</source>
         <translation>Quizás el problema se podría solucionar actualizando esta aplicación.</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="389"/>
+        <location filename="../browserwindow.cpp" line="548"/>
         <source>About this release</source>
         <translation>Acerca de esta version</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="390"/>
+        <location filename="../browserwindow.cpp" line="549"/>
         <source>Due to changes in YouTube, the old SMTube doesn&apos;t work anymore.</source>
         <translation>Debido a cambios en YouTube, la versión anterior de SMTube ha dejado de funcionar.</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="391"/>
+        <location filename="../browserwindow.cpp" line="550"/>
         <source>This is a new version of SMTube, written from scratch.</source>
         <translation>Esta es una versión totalmente nueva, escrita desde cero.</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="392"/>
+        <location filename="../browserwindow.cpp" line="551"/>
         <source>Some functionality is not available yet.</source>
         <translation>Todavía no están disponible todas las funciones.</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="394"/>
+        <location filename="../browserwindow.cpp" line="553"/>
         <source>Important:</source>
         <translation>Importante:</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="395"/>
+        <location filename="../browserwindow.cpp" line="554"/>
         <source>If the VEVO videos fail to play, please use the option %1 in the Help menu.</source>
         <translation>Si los vídeos VEVO no se reproducen, por favor usa la opción %1 del menú Ayuda.</translation>
     </message>
     <message>
-        <location filename="../browserwindow.cpp" line="396"/>
+        <location filename="../browserwindow.cpp" line="555"/>
         <source>Update the YouTube code</source>
         <translation>Actualizar el código de YouTube</translation>
     </message>
     <message>
-        <source>About</source>
-        <translation type="obsolete">Acerca de</translation>
-    </message>
-    <message>
-        <location filename="../browserwindow.cpp" line="211"/>
+        <location filename="../browserwindow.cpp" line="284"/>
         <source>Loading... %1%</source>
         <translation>Cargando... %1%</translation>
     </message>
-    <message>
-        <source>About SMTube</source>
-        <translation type="obsolete">Acerca de SMTube</translation>
-    </message>
-    <message>
-        <source>This is an early version of the new SMTube.</source>
-        <translation type="obsolete">Esta es una versión preliminar del nuevo SMTube.</translation>
-    </message>
-    <message>
-        <source>Many things are still missing.</source>
-        <translation type="obsolete">Todavía faltan muchas cosas.</translation>
-    </message>
-    <message>
-        <source>License: %1</source>
-        <translation type="obsolete">Licencia: %1</translation>
-    </message>
-    <message>
-        <source>Version: %1</source>
-        <translation type="obsolete">Versión: %1</translation>
-    </message>
 </context>
 <context>
     <name>CodeDownloader</name>
@@ -306,73 +296,89 @@
         <translation>Configuración</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="24"/>
+        <location filename="../configdialog.ui" line="27"/>
         <source>&amp;General</source>
         <translation>&amp;General</translation>
     </message>
     <message>
-        <source>Playback &amp;quality:</source>
-        <translation type="obsolete">Calidad de re&amp;producción:</translation>
-    </message>
-    <message>
+        <location filename="../configdialog.ui" line="108"/>
         <source>&amp;Players</source>
-        <translation type="obsolete">&amp;Reproductores</translation>
+        <translation>&amp;Reproductores</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="111"/>
+        <location filename="../configdialog.ui" line="156"/>
         <source>Add</source>
         <translation>Añadir</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="76"/>
+        <location filename="../configdialog.ui" line="121"/>
         <source>Up</source>
         <translation>Subir</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="30"/>
+        <location filename="../configdialog.ui" line="33"/>
         <source>Playback</source>
         <translation>Reproducción</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="36"/>
+        <location filename="../configdialog.ui" line="39"/>
         <source>Preferred &amp;quality:</source>
         <translation>Calidad &amp;preferida:</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="65"/>
-        <source>Players</source>
-        <translation>Reproductores</translation>
-    </message>
-    <message>
-        <location filename="../configdialog.ui" line="122"/>
+        <location filename="../configdialog.ui" line="167"/>
         <source>Delete</source>
         <translation>Borrar</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="146"/>
+        <location filename="../configdialog.ui" line="191"/>
         <source>Edit</source>
         <translation>Editar</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="87"/>
+        <location filename="../configdialog.ui" line="204"/>
+        <source>A&amp;dd predefined players</source>
+        <translation>Añadir &amp;reproductores predeterminados</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="240"/>
+        <source>&amp;Interface</source>
+        <translation>&amp;Interfaz</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="248"/>
+        <source>&amp;Style:</source>
+        <translation>&amp;Estilo:</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="284"/>
+        <source>Font:</source>
+        <translation>Tipo de letra:</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="298"/>
+        <source>C&amp;hange...</source>
+        <translation>Ca&amp;mbiar...</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="68"/>
+        <source>Download</source>
+        <translation>Descargas</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="74"/>
+        <source>Download videos using an &amp;external service</source>
+        <translation>Descargar vídeos usando un servicio &amp;externo</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="132"/>
         <source>Down</source>
         <translation>Bajar</translation>
     </message>
     <message>
-        <source>Name</source>
-        <translation type="obsolete">Nombre</translation>
-    </message>
-    <message>
-        <source>Binary</source>
-        <translation type="obsolete">Ejecutable</translation>
-    </message>
-    <message>
-        <source>Parameters</source>
-        <translation type="obsolete">Parámetros</translation>
-    </message>
-    <message>
-        <source>Support for</source>
-        <translation type="obsolete">Soporte para</translation>
+        <location filename="../configdialog.cpp" line="81"/>
+        <source>Default</source>
+        <translation>Predeterminado</translation>
     </message>
 </context>
 <context>
@@ -386,28 +392,48 @@
 <context>
     <name>MyWebView</name>
     <message>
-        <location filename="../mywebview.cpp" line="32"/>
+        <location filename="../mywebview.cpp" line="36"/>
         <source>Open link in a web browser</source>
         <translation>Abrir enlace en un navegador web</translation>
     </message>
     <message>
-        <location filename="../mywebview.cpp" line="74"/>
-        <location filename="../mywebview.cpp" line="82"/>
+        <location filename="../mywebview.cpp" line="52"/>
+        <source>Open link in new window</source>
+        <translation>Abrir enlace en una nueva ventana</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="75"/>
+        <source>Open audio with</source>
+        <translation>Abrir audio con</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="99"/>
+        <location filename="../mywebview.cpp" line="124"/>
         <source>Open with %1</source>
         <translation>Abrir con %1</translation>
     </message>
     <message>
-        <location filename="../mywebview.cpp" line="90"/>
+        <location filename="../mywebview.cpp" line="131"/>
+        <source>Open audio with %1</source>
+        <translation>Abrir audio con %1</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="49"/>
         <source>Copy link to clipboard</source>
         <translation>Copiar enlace al portapapeles</translation>
     </message>
     <message>
-        <location filename="../mywebview.cpp" line="93"/>
+        <location filename="../mywebview.cpp" line="48"/>
+        <source>Save link...</source>
+        <translation>Descargar enlace...</translation>
+    </message>
+    <message>
+        <location filename="../mywebview.cpp" line="50"/>
         <source>Open link in this window</source>
         <translation>Abrir enlace en esta ventana</translation>
     </message>
     <message>
-        <location filename="../mywebview.cpp" line="96"/>
+        <location filename="../mywebview.cpp" line="51"/>
         <source>Copy text to clipboard</source>
         <translation>Copiar texto al portapapeles</translation>
     </message>
@@ -417,7 +443,7 @@
     <message>
         <location filename="../playerdialog.ui" line="14"/>
         <source>Edit Player</source>
-        <translation>Edtar Reproductor</translation>
+        <translation>Editar Reproductor</translation>
     </message>
     <message>
         <location filename="../playerdialog.ui" line="22"/>
@@ -439,18 +465,45 @@
         <source>This player supports &amp;video sites</source>
         <translation>Este reproductor incorpora soporte para webs de &amp;vídeos</translation>
     </message>
-</context>
-<context>
-    <name>QObject</name>
     <message>
-        <location filename="../players.cpp" line="101"/>
-        <source>Video sites</source>
-        <translation>Webs de vídeos</translation>
+        <location filename="../playerdialog.ui" line="78"/>
+        <source>This player can play &amp;online TV</source>
+        <translation>Este reproductor puede reproducir TV &amp;online</translation>
     </message>
     <message>
-        <location filename="../players.cpp" line="101"/>
-        <source>Normal streams</source>
-        <translation>Datos normales</translation>
+        <location filename="../playerdialog.ui" line="87"/>
+        <source>Preferred &amp;quality:</source>
+        <translation>Calidad pre&amp;ferida:</translation>
+    </message>
+    <message>
+        <location filename="../playerdialog.ui" line="117"/>
+        <source>Add to &amp;menu:</source>
+        <translation>Añadir al &amp;menú:</translation>
+    </message>
+    <message>
+        <location filename="../playerdialog.cpp" line="28"/>
+        <source>None</source>
+        <translation>Ninguno</translation>
+    </message>
+    <message>
+        <location filename="../playerdialog.cpp" line="29"/>
+        <source>Video</source>
+        <translation>Vídeo</translation>
+    </message>
+    <message>
+        <location filename="../playerdialog.cpp" line="30"/>
+        <source>Audio</source>
+        <translation>Audio</translation>
+    </message>
+    <message>
+        <location filename="../playerdialog.cpp" line="31"/>
+        <source>Video and audio</source>
+        <translation>Vídeo y audio</translation>
+    </message>
+    <message>
+        <location filename="../playerdialog.cpp" line="33"/>
+        <source>Default</source>
+        <translation>Predeterminada</translation>
     </message>
 </context>
 </TS>
